==> nextcloud-app-spreed-1%3A8.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ro.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "None" : "Niciuna",
    "User" : "Utilizator",
    "Everyone" : "Toți",
    "Disabled" : "Dezactivați",
    "Users" : "Utilizatori",
    "Copy link" : "Copiză link",
    "Favorite" : "Favorite",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adăugați la favorite",
    "Contacts" : "Contacte",
    "Groups" : "Grupuri",
    "Circles" : "Cercuri",
    "Loading" : "Loading",
    "Error" : "Eroare",
    "Password protect" : "Protejare cu parolă",
    "Back" : "Înapoi",
    "Close" : "Închide",
    "Reply" : "Răspunde",
    "Today" : "Azi",
    "Yesterday" : "Ieri",
    "guest" : "invitat",
    "No results" : "Niciun rezultat",
    "Share link" : "Partajează link-ul",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Edit" : "Editează",
    "Limit to groups" : "Limitează pentru grupuri",
    "Limit app usage to groups." : "Limitare utilizare aplicație la grupuri",
    "Save changes" : "Salvează modificările",
    "Saving …" : "Se salvează",
    "Saved!" : "Salvat!",
    "Name" : "Nume",
    "Saved" : "Salvat",
    "Password required" : "Parola este necesară",
    "Password" : "Parolă",
    "Cancel" : "Anulează",
    "Submit" : "Trimite",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Android app" : "Aplicație Android",
    "iOS app" : "Aplicație iOS",
    "Copy" : "Copiază",
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "Share" : "Partajează",
    "Change password" : "Schimbă parola",
    "Set password" : "Setare parolă",
    "Rename" : "Redenumire",
    "Send" : "Trimite",
    "Error while sharing" : "Eroare la partajare",
    "Favorited" : "Adăugate la favorite",
    ", " : ","
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ro.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Limit to groups" : "Limitează pentru grupuri",
    "Everyone" : "Toți",
    "Save changes" : "Salvează modificările",
    "Saving …" : "Se salvează",
    "Saved!" : "Salvat!",
    "None" : "Niciuna",
    "User" : "Utilizator",
    "Disabled" : "Dezactivați",
    "Users" : "Utilizatori",
    "Name" : "Nume",
    "Saved" : "Salvat",
    "Copy link" : "Copiză link",
    "Favorite" : "Favorite",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adăugați la favorite",
    "Contacts" : "Contacte",
    "Loading" : "Loading",
    "Groups" : "Grupuri",
    "Circles" : "Cercuri",
    "Error" : "Eroare",
    "Password protect" : "Protejare cu parolă",
    "Back" : "Înapoi",
    "Close" : "Închide",
    "Reply" : "Răspunde",
    "Today" : "Azi",
    "Yesterday" : "Ieri",
    "guest" : "invitat",
    "No results" : "Niciun rezultat",
    "Settings" : "Setări",
    "Edit" : "Editează",
    "Dismiss" : "Elimină",
    "Share link" : "Partajează link-ul",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "Afișare în grilă",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Password" : "Parolă",
    "Android app" : "Aplicație Android",
    "iOS app" : "Aplicație iOS",
    "Copy" : "Copiază",
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "Password required" : "Parola este necesară",
    "Cancel" : "Anulează",
    "Submit" : "Trimite",
    "Change password" : "Schimbă parola",
    "Set password" : "Setare parolă",
    "Rename" : "Redenumire",
    "Send" : "Trimite",
    "Share" : "Partajează",
    "Error while sharing" : "Eroare la partajare",
    "Favorited" : "Adăugate la favorite",
    "Limit app usage to groups." : "Limitare utilizare aplicație la grupuri"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
